==> nearby_messages_api-0.0.9.tar.gz: android/src/main/java/org/chmoder/nearby_messages_api/NearbyMessagesApiPlugin.java <==
package org.chmoder.nearby_messages_api;

import android.app.Activity;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.provider.Settings;
import android.support.annotation.NonNull;
import android.support.v4.content.LocalBroadcastManager;
import android.util.Log;

import com.google.android.gms.nearby.Nearby;
import com.google.android.gms.nearby.messages.Message;
import com.google.android.gms.nearby.messages.MessageListener;
import com.google.android.gms.nearby.messages.PublishOptions;
import com.google.android.gms.nearby.messages.Strategy;
import com.google.android.gms.nearby.messages.SubscribeOptions;
import com.google.android.gms.tasks.OnFailureListener;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import static android.content.ContentValues.TAG;

/**
 * NearbyMessagesApiPlugin
 */
public class NearbyMessagesApiPlugin extends BroadcastReceiver implements MethodCallHandler {
    private final Activity activity;
    private final Registrar registrar;
    private final MethodChannel channel;
    private Message mActiveMessage;
    private PendingIntent pendingIntent;
    private MessageListener mMessageListener;

    /**
     * set up the broadcast receiver and nearby message listener
     * @param activity
     * @param registrar
     * @param methodChannel
     */
    private NearbyMessagesApiPlugin(Activity activity, Registrar registrar, MethodChannel methodChannel) {
        this.activity = activity;
        this.registrar = registrar;
        this.channel = methodChannel;

        LocalBroadcastManager manager = LocalBroadcastManager.getInstance(registrar.context());
        manager.registerReceiver(this, new IntentFilter());
    }

    /**
     * Plugin registration.
     */
    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(
                registrar.messenger(),
                "nearby_messages_api"
        );
        final NearbyMessagesApiPlugin plugin = new NearbyMessagesApiPlugin(
                registrar.activity(),
                registrar,
                channel
        );
        channel.setMethodCallHandler(plugin);
    }

    /**
     * attache the nearby messages listener to a broadcast receiver
     * background service can pass messages to the host this way
     * @param context
     * @param intent
     */
    @Override
    public void onReceive(Context context, Intent intent) {
        Nearby.getMessagesClient(context).handleIntent(intent, getMessageListener());
    }

    /**
     * background receiver subscription
     */
    void backgroundSubscribe() {
        Log.i(TAG, "Subscribing for background updates.");
        SubscribeOptions options = new SubscribeOptions.Builder()
                .setStrategy(Strategy.BLE_ONLY)
                .build();
        Nearby.getMessagesClient(activity).subscribe(getPendingIntent(), options).addOnFailureListener(activity, new OnFailureListener() {
            @Override
            public void onFailure(@NonNull Exception e) {
                Log.e(TAG, "FAILED TO SUBSCRIBE");
                Log.e(TAG, e.toString());
            }
        });
    }

    /**
     * unsubscribe from broadcast receiver
     */
    void backgroundUnsubscribe() {
        Log.i(TAG, "Unsubscribing from background updates");
        Nearby.getMessagesClient(activity).unsubscribe(getPendingIntent());
        pendingIntent = null;
    }

    void foregroundSubscribe() {
        Nearby.getMessagesClient(activity).subscribe(getMessageListener());
    }

    void foregroundUnsubscribe() {
        Nearby.getMessagesClient(activity).unsubscribe(getMessageListener());
    }

    private MessageListener getMessageListener() {
        if(mMessageListener == null) {
            mMessageListener = new MessageListener() {
                @Override
                public void onFound(Message message) {
                    Log.i(TAG, "Found message via PendingIntent: " + message);
                    String messageContent = new String(message.getContent());
                    channel.invokeMethod("onFound", messageContent);
                }

                @Override
                public void onLost(Message message) {
                    Log.i(TAG, "Lost message via PendingIntent: " + message);
                    String messageContent = new String(message.getContent());
                    channel.invokeMethod("onLost", messageContent);
                }
            };
        }
        return mMessageListener;
    }

    /**
     * makes this class a pending intent for the broadcast receiver
     * @return
     */
    private PendingIntent getPendingIntent() {
        if (pendingIntent == null) {
            pendingIntent = PendingIntent.getBroadcast(
                    activity,
                    0,
                    new Intent(activity, NearbyMessagesApiPlugin.class),
                    PendingIntent.FLAG_UPDATE_CURRENT);

        }
        return pendingIntent;
    }

    void publish() {
        unPublish();

        String deviceId = Settings.Secure.getString(activity.getContentResolver(),
                Settings.Secure.ANDROID_ID);

        Log.i(TAG, "Publishing message " + deviceId);

        mActiveMessage = new Message(deviceId.getBytes());
        Strategy strategy = new Strategy.Builder()
                .setDiscoveryMode(Strategy.DISCOVERY_MODE_SCAN)
                .setTtlSeconds(Strategy.TTL_SECONDS_MAX)
                .build();

        PublishOptions options = new PublishOptions.Builder()
                .setStrategy(strategy)
                .build();
        Nearby.getMessagesClient(activity).publish(mActiveMessage, options).addOnFailureListener(activity, new OnFailureListener() {
            @Override
            public void onFailure(@NonNull Exception e) {
                Log.e(TAG, "FAILED TO PUBLISH");
                Log.e(TAG, e.toString());
            }
        });
    }

    void unPublish() {
        if (mActiveMessage != null) {
            Nearby.getMessagesClient(activity).unpublish(mActiveMessage);
            mActiveMessage = null;
        }
    }

    /**
     * Host will invoke these methods to set up the nearby messages API listener
     * @param call
     * @param result
     */
    @Override
    public void onMethodCall(MethodCall call, Result result) {
        switch (call.method) {
            case "getPlatformVersion":
                result.success("Android " + android.os.Build.VERSION.RELEASE);
                break;
            case "backgroundSubscribe":
                this.backgroundSubscribe();
                result.success(null);
                break;
            case "backgroundUnsubscribe":
                this.backgroundUnsubscribe();
                result.success(null);
            case "foregroundSubscribe":
                this.foregroundSubscribe();
                result.success(null);
                break;
            case "foregroundUnsubscribe":
                this.foregroundUnsubscribe();
                result.success(null);
                break;
            case "publish":
                this.publish();
                result.success(null);
                break;
            case "unPublish":
                this.unPublish();
                result.success(null);
                break;
            default:
                result.notImplemented();
        }
    }
}

==> nearby_messages_api-0.0.14.tar.gz: android/src/main/java/org/chmoder/nearby_messages_api/NearbyMessagesApiPlugin.java <==
package org.chmoder.nearby_messages_api;

import android.app.Activity;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.provider.Settings;
import android.support.annotation.NonNull;
import android.support.v4.content.LocalBroadcastManager;
import android.util.Log;

import com.google.android.gms.nearby.Nearby;
import com.google.android.gms.nearby.messages.Message;
import com.google.android.gms.nearby.messages.MessageListener;
import com.google.android.gms.nearby.messages.PublishOptions;
import com.google.android.gms.nearby.messages.Strategy;
import com.google.android.gms.nearby.messages.SubscribeOptions;
import com.google.android.gms.tasks.OnCanceledListener;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import static android.content.ContentValues.TAG;

/**
 * NearbyMessagesApiPlugin
 */
public class NearbyMessagesApiPlugin extends BroadcastReceiver implements MethodCallHandler {
//    private Activity activity;
    private Registrar registrar;
    private MethodChannel channel;
    private Message mActiveMessage;
    private PendingIntent pendingIntent;
    private MessageListener mMessageListener;
    private static NearbyMessagesApiPlugin instance;

    private NearbyMessagesApiPlugin() {
    }

    static {
        instance = new NearbyMessagesApiPlugin();
    }

    /** Static 'instance' method */
    public static NearbyMessagesApiPlugin getInstance() {
        return instance;
    }

    /**
     * set up the broadcast receiver and nearby message listener
     * @param activity
     * @param registrar
     * @param methodChannel
     */
    private NearbyMessagesApiPlugin(Activity activity, Registrar registrar, MethodChannel methodChannel) {
//        this.activity = activity;
        this.registrar = registrar;
        this.channel = methodChannel;

        LocalBroadcastManager manager = LocalBroadcastManager.getInstance(registrar.context());
        manager.registerReceiver(this, new IntentFilter());
    }

    /**
     * Plugin registration.
     */
    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(
                registrar.messenger(),
                "nearby_messages_api"
        );
        final NearbyMessagesApiPlugin plugin = new NearbyMessagesApiPlugin(
                registrar.activity(),
                registrar,
                channel
        );
        channel.setMethodCallHandler(plugin);
    }

    /**
     * attache the nearby messages listener to a broadcast receiver
     * background service can pass messages to the host this way
     * @param context
     * @param intent
     */
    @Override
    public void onReceive(Context context, Intent intent) {
        Nearby.getMessagesClient(context).handleIntent(intent, getMessageListener());
    }

    /**
     * background receiver subscription
     */
    void backgroundSubscribe() {
        Log.i(TAG, "Subscribing for background updates.");

        SubscribeOptions options = new SubscribeOptions.Builder()
                .setStrategy(Strategy.BLE_ONLY)
                .build();

        Nearby.getMessagesClient(registrar.activity()).subscribe(
                getPendingIntent(),
                options
        )
                .addOnFailureListener(registrar.activity(), new OnFailureListener() {
                    @Override
                    public void onFailure(@NonNull Exception e) {
                        Log.e(TAG, "FAILED TO SUBSCRIBE In Background");
                        Log.e(TAG, e.toString());
                    }
                })
        .addOnCanceledListener(registrar.activity(), new OnCanceledListener() {
            @Override
            public void onCanceled() {
                Log.e(TAG, "CANCELED SUBSCRIBE IN BACKGROUND");
            }
        })
        .addOnSuccessListener(registrar.activity(), new OnSuccessListener<Void>() {
            @Override
            public void onSuccess(Void aVoid) {
                Log.e(TAG, "SUCCESS Subscribe In Background");
            }
        });
    }

    /**
     * unsubscribe from broadcast receiver
     */
    void backgroundUnsubscribe() {
        Log.i(TAG, "Unsubscribing from background updates");
        Nearby.getMessagesClient(registrar.activity())
                .unsubscribe(
                        getPendingIntent()
                );
        pendingIntent = null;
    }

    void foregroundSubscribe() {
        Log.i(TAG, "Subscribing to foreground updates");
        Nearby.getMessagesClient(registrar.activity()).subscribe(getMessageListener());
    }

    void foregroundUnsubscribe() {
        Log.i(TAG, "Unsubscribing from foreground updates");
        Nearby.getMessagesClient(registrar.activity()).unsubscribe(getMessageListener());
    }

    private MessageListener getMessageListener() {
        final MethodChannel localChannel = getInstance().channel;

        if(mMessageListener == null) {
            mMessageListener = new MessageListener() {
                @Override
                public void onFound(Message message) {
                    Log.i(TAG, "Found message: " + message);
                    String messageContent = new String(message.getContent());
                    localChannel.invokeMethod("onFound", messageContent);
                }

                @Override
                public void onLost(Message message) {
                    Log.i(TAG, "Lost message: " + message);
                    String messageContent = new String(message.getContent());
                    localChannel.invokeMethod("onLost", messageContent);
                }
            };
        }
        return mMessageListener;
    }

    /**
     * makes this class a pending intent for the broadcast receiver
     * @return
     */
    private PendingIntent getPendingIntent() {
        if (pendingIntent == null) {
            Log.i(TAG, "getting pending intent");
            Intent serviceIntent = new Intent(registrar.activity(), NearbyMessagesApiPlugin.class);
            pendingIntent = PendingIntent.getService(registrar.activity(), 0,
                    serviceIntent, PendingIntent.FLAG_CANCEL_CURRENT);
        }
        return pendingIntent;
    }

    void publish() {
        unPublish();

        String deviceId = Settings.Secure.getString(registrar.activity().getContentResolver(),
                Settings.Secure.ANDROID_ID);

        Log.i(TAG, "Publishing message " + deviceId);

        mActiveMessage = new Message(deviceId.getBytes());
        Strategy strategy = new Strategy.Builder()
                .setDiscoveryMode(Strategy.DISCOVERY_MODE_SCAN)
                .setTtlSeconds(Strategy.TTL_SECONDS_MAX)
                .build();

        PublishOptions options = new PublishOptions.Builder()
                .setStrategy(strategy)
                .build();

        Nearby.getMessagesClient(registrar.activity()).publish(mActiveMessage, options).addOnFailureListener(registrar.activity(), new OnFailureListener() {
            @Override
            public void onFailure(@NonNull Exception e) {
                Log.e(TAG, "FAILED TO PUBLISH");
                Log.e(TAG, e.toString());
            }
        });
    }

    void unPublish() {
        if (mActiveMessage != null) {
            Nearby.getMessagesClient(registrar.activity()).unpublish(mActiveMessage);
            mActiveMessage = null;
        }
    }

    /**
     * Host will invoke these methods to set up the nearby messages API listener
     * @param call
     * @param result
     */
    @Override
    public void onMethodCall(MethodCall call, Result result) {
        switch (call.method) {
            case "getPlatformVersion":
                result.success("Android " + android.os.Build.VERSION.RELEASE);
                break;
            case "backgroundSubscribe":
                this.backgroundSubscribe();
                result.success(null);
                break;
            case "backgroundUnsubscribe":
                this.backgroundUnsubscribe();
                result.success(null);
            case "foregroundSubscribe":
                this.foregroundSubscribe();
                result.success(null);
                break;
            case "foregroundUnsubscribe":
                this.foregroundUnsubscribe();
                result.success(null);
                break;
            case "publish":
                this.publish();
                result.success(null);
                break;
            case "unPublish":
                this.unPublish();
                result.success(null);
                break;
            default:
                result.notImplemented();
        }
    }
}
